@@ -1,17 +1,30 @@
 package Config::MVP::Section;
-our $VERSION = '0.092100';
+our $VERSION = '0.092210';
 
 use Moose;
 # ABSTRACT: one section of an MVP configuration sequence
 
 
 has name    => (is => 'ro', isa => 'Str',       required => 1);
-has package => (is => 'ro', isa => 'ClassName', required => 0);
+has package => (
+  is  => 'ro',
+  isa => 'Str', # should be class-like string, but can't be ClassName
+  required  => 0,
+  predicate => 'has_package',
+);
 
 has multivalue_args => (
-  is  => 'ro',
-  isa => 'ArrayRef',
-  default => sub { [] },
+  is   => 'ro',
+  isa  => 'ArrayRef',
+  lazy => 1,
+  default => sub {
+    my ($self) = @_;
+
+    return []
+      unless $self->has_package and $self->package->can('mvp_multivalue_args');
+
+    return [ $self->package->mvp_multivalue_args ];
+  },
 );
 
 has payload => (
@@ -24,9 +37,38 @@ has payload => (
 has aliases => (
   is  => 'ro',
   isa => 'HashRef',
-  default => sub { {} },
+  default => sub {
+    my ($self) = @_;
+
+    return {} unless $self->has_package and $self->package->can('mvp_aliases');
+
+    return $self->package->mvp_aliases;
+  },
 );
 
+sub _BUILD_package_settings {
+  my ($self) = @_;
+
+  return unless defined (my $pkg  = $self->package);
+
+  # We already inspected this plugin.
+  confess "illegal package name $pkg" unless Params::Util::_CLASS($pkg);
+
+  my $name = $self->name;
+  eval "require $pkg; 1"
+    or confess "couldn't load plugin $name given in config: $@";
+
+  # We call these accessors for lazy attrs to ensure they're initialized from
+  # defaults if needed.  Crash early! -- rjbs, 2009-08-09
+  $self->multivalue_args;
+  $self->aliases;
+}
+
+sub BUILD {
+  my ($self) = @_;
+  $self->_BUILD_package_settings;
+}
+
 sub add_value {
   my ($self, $name, $value) = @_;
 
@@ -62,7 +104,7 @@ Config::MVP::Section - one section of an MVP configuration sequence
 
 =head1 VERSION
 
-version 0.092100
+version 0.092210
 
 =head1 DESCRIPTION
 
@@ -85,7 +127,7 @@ aliases hashref is:
 This software is copyright (c) 2009 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
+the same terms as the Perl 5 programming language system itself.
 
 =cut 
 
